#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-gi-base
version:              0.25.0
visibility:           public
id:                   haskell-gi-base-0.25.0-B0EKu6aa0lqDuuFsIBiZKt
key:                  haskell-gi-base-0.25.0-B0EKu6aa0lqDuuFsIBiZKt
license:              LGPL-2.1-only
maintainer:           Iñaki García Etxebarria (inaki@blueleaf.cc)
author:
    Will Thompson,
    Iñaki García Etxebarria,
    Jonas Platte

stability:            Experimental
homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:             Foundation for libraries generated by haskell-gi
description:          Foundation for libraries generated by haskell-gi
category:             Development
abi:                  654bdee52223205dbcf09f50a2ce7e5f
exposed:              True
exposed-modules:
    Data.GI.Base Data.GI.Base.Attributes Data.GI.Base.BasicConversions
    Data.GI.Base.BasicTypes Data.GI.Base.CallStack
    Data.GI.Base.Constructible Data.GI.Base.GArray
    Data.GI.Base.GClosure Data.GI.Base.GError Data.GI.Base.GHashTable
    Data.GI.Base.GObject Data.GI.Base.GParamSpec Data.GI.Base.GQuark
    Data.GI.Base.GType Data.GI.Base.GValue Data.GI.Base.GVariant
    Data.GI.Base.Internal.CTypes Data.GI.Base.ManagedPtr
    Data.GI.Base.Overloading Data.GI.Base.Properties
    Data.GI.Base.ShortPrelude Data.GI.Base.Signals Data.GI.Base.Utils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/haskell-gi-base-0.25.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/haskell-gi-base-0.25.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/haskell-gi-base-0.25.0
hs-libraries:         HShaskell-gi-base-0.25.0-B0EKu6aa0lqDuuFsIBiZKt
extra-libraries:      gobject-2.0 glib-2.0
include-dirs:         /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-gi-base/html/haskell-gi-base.haddock
haddock-html:         /usr/share/doc/haskell-gi-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

